==> snap-rcp-3.0.2-20160504.124053-9-sources.jar: org/esa/snap/rcp/bandmaths/Bundle.java <==
package org.esa.snap.rcp.bandmaths;
/** Localizable strings for {@link org.esa.snap.rcp.bandmaths}. */
@javax.annotation.Generated(value="org.netbeans.modules.openide.util.NbBundleProcessor")
class Bundle {
    /**
     * @return <i>Band Maths...</i>
     * @see BandMathsAction
     */
    static String CTL_BandMathsAction_MenuText() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_BandMathsAction_MenuText");
    }
    /**
     * @return <i>Create a new band using an arbitrary mathematical expression</i>
     * @see BandMathsAction
     */
    static String CTL_BandMathsAction_ShortDescription() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_BandMathsAction_ShortDescription");
    }
    /**
     * @return <i>You cannot reference the target band ''</i>{@code arg0}<i>'' within the expression.</i>
     * @see BandMathsDialog
     */
    static String CTL_BandMathsDialog_ErrBandCannotBeReferenced(Object arg0) {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_BandMathsDialog_ErrBandCannotBeReferenced", arg0);
    }
    /**
     * @return <i>The band could not be created.<br>An expression parse error occurred:<br></i>
     * @see BandMathsDialog
     */
    static String CTL_BandMathsDialog_ErrBandNotCreated() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_BandMathsDialog_ErrBandNotCreated");
    }
    /**
     * @return <i>Please check the band maths expression you have entered.<br>It is not valid.</i>
     * @see BandMathsDialog
     */
    static String CTL_BandMathsDialog_ErrExpressionNotValid() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_BandMathsDialog_ErrExpressionNotValid");
    }
    /**
     * @return <i>Band maths expression:</i>
     * @see BandMathsDialog
     */
    static String CTL_BandMathsDialog_LblExpression() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_BandMathsDialog_LblExpression");
    }
    /**
     * @return <i>Band Maths</i>
     * @see BandMathsDialog
     */
    static String CTL_BandMathsDialog_Title() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_BandMathsDialog_Title");
    }
    /**
     * @return <i>The band name ''</i>{@code arg0}<i>'' is not valid.<br><br>Names must not start with a dot and must not<br>contain any of the following characters: \/:*?"&lt;>|</i>
     * @see ProductNodeNameValidator
     */
    static String CTL_PNNV_ExMsg_ContainedCharacter(Object arg0) {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_PNNV_ExMsg_ContainedCharacter", arg0);
    }
    /**
     * @return <i>The band name must be unique within the product scope.<br>The scope comprises bands and tie-point grids.</i>
     * @see ProductNodeNameValidator
     */
    static String CTL_PNNV_ExMsg_UniqueBandName() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_PNNV_ExMsg_UniqueBandName");
    }
    /**
     * @return <i>Propagate Uncertainty...</i>
     * @see PropagateUncertaintyAction
     */
    static String CTL_PropagateUncertaintyAction_MenuText() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_PropagateUncertaintyAction_MenuText");
    }
    /**
     * @return <i>Perform Gaussian uncertainty propagation from virtual band according to GUM 1995, chapter 5</i>
     * @see PropagateUncertaintyAction
     */
    static String CTL_PropagateUncertaintyAction_ShortDescription() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_PropagateUncertaintyAction_ShortDescription");
    }
    /**
     * @return <i>Propagate Uncertainty</i>
     * @see PropagateUncertaintyDialog
     */
    static String CTL_PropagateUncertaintyDialog_Title() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_PropagateUncertaintyDialog_Title");
    }
    private void Bundle() {}
}

==> snap-rcp-5.0.8-20170727.054422-18-sources.jar: org/esa/snap/rcp/bandmaths/Bundle.java <==
package org.esa.snap.rcp.bandmaths;
/** Localizable strings for {@link org.esa.snap.rcp.bandmaths}. */
@javax.annotation.Generated(value="org.netbeans.modules.openide.util.NbBundleProcessor")
class Bundle {
    /**
     * @return <i>Band Maths...</i>
     * @see BandMathsAction
     */
    static String CTL_BandMathsAction_MenuText() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_BandMathsAction_MenuText");
    }
    /**
     * @return <i>Create a new band using an arbitrary mathematical expression</i>
     * @see BandMathsAction
     */
    static String CTL_BandMathsAction_ShortDescription() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_BandMathsAction_ShortDescription");
    }
    /**
     * @return <i>You cannot reference the target band ''</i>{@code arg0}<i>'' within the expression.</i>
     * @see BandMathsDialog
     */
    static String CTL_BandMathsDialog_ErrBandCannotBeReferenced(Object arg0) {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_BandMathsDialog_ErrBandCannotBeReferenced", arg0);
    }
    /**
     * @return <i>The band could not be created.<br>An expression parse error occurred:<br></i>
     * @see BandMathsDialog
     */
    static String CTL_BandMathsDialog_ErrBandNotCreated() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_BandMathsDialog_ErrBandNotCreated");
    }
    /**
     * @return <i>Please check the band maths expression you have entered.<br>It is not valid.</i>
     * @see BandMathsDialog
     */
    static String CTL_BandMathsDialog_ErrExpressionNotValid() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_BandMathsDialog_ErrExpressionNotValid");
    }
    /**
     * @return <i>Band maths expression:</i>
     * @see BandMathsDialog
     */
    static String CTL_BandMathsDialog_LblExpression() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_BandMathsDialog_LblExpression");
    }
    /**
     * @return <i>Band Maths</i>
     * @see BandMathsDialog
     */
    static String CTL_BandMathsDialog_Title() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_BandMathsDialog_Title");
    }
    /**
     * @return <i>The band name ''</i>{@code arg0}<i>'' is not valid.<br><br>Names must not start with a dot and must not<br>contain any of the following characters: \/:*?"&lt;>|</i>
     * @see ProductNodeNameValidator
     */
    static String CTL_PNNV_ExMsg_ContainedCharacter(Object arg0) {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_PNNV_ExMsg_ContainedCharacter", arg0);
    }
    /**
     * @return <i>The band name must be unique within the product scope.<br>The scope comprises bands, tie-point grids and masks.</i>
     * @see ProductNodeNameValidator
     */
    static String CTL_PNNV_ExMsg_UniqueBandName() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_PNNV_ExMsg_UniqueBandName");
    }
    /**
     * @return <i>Propagate Uncertainty...</i>
     * @see PropagateUncertaintyAction
     */
    static String CTL_PropagateUncertaintyAction_MenuText() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_PropagateUncertaintyAction_MenuText");
    }
    /**
     * @return <i>Perform Gaussian uncertainty propagation from virtual band according to GUM 1995, chapter 5</i>
     * @see PropagateUncertaintyAction
     */
    static String CTL_PropagateUncertaintyAction_ShortDescription() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_PropagateUncertaintyAction_ShortDescription");
    }
    /**
     * @return <i>Propagate Uncertainty</i>
     * @see PropagateUncertaintyDialog
     */
    static String CTL_PropagateUncertaintyDialog_Title() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_PropagateUncertaintyDialog_Title");
    }
    private Bundle() {}
}
